/*
    *
    * This file is a part of CoreAction.
    * A side bar for showing widgets for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/

#include <QPainter>

#include "calendermanage.h"


calendermanage::calendermanage(QWidget *parent): QCalendarWidget(parent)
{
    m_transparentBrush.setColor(Qt::transparent);
}

calendermanage::~calendermanage()
{
    m_dates.clear();
}

void calendermanage::setEvents(QMap<QDate, QColor> dates)
{
    m_dates = dates;
    repaint();
}

void calendermanage::paintCell(QPainter *painter, const QRect &rect, const QDate &date) const
{
    QCalendarWidget::paintCell(painter, rect, date);

    if (!m_dates.count()) {
        return;
    }

    Q_FOREACH(QDate d, m_dates.keys()) {
        if (d.day() != date.day() || d.month() != date.month() || d.year() != date.year()) {
            continue;
        }

        painter->setPen(m_dates[d]);
        painter->setBrush(m_transparentBrush);
        painter->drawRect(rect.adjusted(0, 0, -1, -1));
    }
}
