/*
    *
    * This file is a part of CoreAction.
    * A side bar for showing widgets for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/

#include <QtWidgets>

#include <cprime/settingsmanage.h>
#include <cprime/corexdg.h>
#include <cprime/applicationdialog.h>
#include <cprime/cvariables.h>
#include <cprime/appopenfunc.h>

#include "wfavourites.h"


/* CoreXdgMime instance */
CoreXdgMime *mimeHandler = CoreXdgMime::instance();

wFavourites::wFavourites(QWidget *parent) : QWidget(parent)
{
    settingsManage *sm = settingsManage::initialize();
    appsList = sm->value("CoreApps", "Favourite");

    QHBoxLayout *lyt = new QHBoxLayout();
    lyt->addStretch();

    QButtonGroup *appBtnGrp = new QButtonGroup();
    connect(appBtnGrp, SIGNAL(buttonClicked(int)), this, SLOT(startApp(int)));

    if (!appsList.count()) {
        lyt->addWidget(new QLabel("Favourite Apps not set."));
    } else {
        for (int i = 0; i < appsList.count(); i++) {
            QString app = appsList.value(i);
            CoreDesktopFile file = mimeHandler->desktopForName( app );

			QToolButton *appBtn = new QToolButton();
            appBtn->setIcon(CPrime::ThemeFunc::getAppIcon(file.desktopName()));
            appBtn->setIconSize( QSize(sm->value("CoreApps", "ToolBarIconSize")) );
            appBtnGrp->addButton(appBtn, i);

            lyt->addWidget(appBtn);
		}
	}

    lyt->addStretch();

    setLayout(lyt);
}

void wFavourites::startApp(int idx)
{
    QString app = appsList.value(idx);
    CoreDesktopFile file = mimeHandler->desktopForName( app );
    file.startApplication();
}

/* Name of the plugin */
QString favouritesPlugin::name()
{
    return "Favourite Apps";
}

/* The plugin version */
QString favouritesPlugin::version()
{
    return QString(VERSION_TEXT);
}

/* The Widget hooks for menus/toolbars */
QWidget *favouritesPlugin::widget(QWidget *parent)
{
    return new wFavourites(parent);
}
