/*
    *
    * This file is a part of CoreAction.
    * A side bar for showing widgets for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/

#include <QTimer>

#include <cprime/filefunc.h>
#include <csys/info_manager.h>

#include "wnetwork.h"
#include "ui_wnetwork.h"


wNetwork::wNetwork(QWidget *parent) : QWidget(parent), ui(new Ui::wNetwork),
    info(InfoManager::ins())
{
    ui->setupUi(this);

    checkNetwork();
    QTimer *timer = new QTimer();
    timer->start(1000);

    connect(timer, &QTimer::timeout, this, &wNetwork::checkNetwork);
}

wNetwork::~wNetwork()
{
    delete ui;
}

void wNetwork::checkNetwork()
{
    static quint64 l_RXbytes = info->getRXbytes();
    static quint64 l_TXbytes = info->getTXbytes();
    static quint64 max_RXbytes = 1L << 20; // 1 MEBI
    static quint64 max_TXbytes = 1L << 20; // 1 MEBI

    quint64 RXbytes = info->getRXbytes();
    quint64 TXbytes = info->getTXbytes();

    quint64 d_RXbytes = (RXbytes - l_RXbytes);
    quint64 d_TXbytes = (TXbytes - l_TXbytes);

    // Function from utilities.cpp
    QString downText = CPrime::FileFunc::formatSize(static_cast<quint64>(d_RXbytes));
    QString upText = CPrime::FileFunc::formatSize(static_cast<quint64>(d_TXbytes));

    ui->dspeed->setText("Download " + downText);
    ui->uspeed->setText("Upload " + upText);

    max_RXbytes = qMax(max_RXbytes, d_RXbytes);
    max_TXbytes = qMax(max_TXbytes, d_TXbytes);

    l_RXbytes = RXbytes;
    l_TXbytes = TXbytes;
}

/* Name of the plugin */
QString networkPlugin::name()
{
    return "Network";
}

/* The plugin version */
QString networkPlugin::version()
{
    return QString(VERSION_TEXT);
}

/* The Widget hooks for menus/toolbars */
QWidget *networkPlugin::widget(QWidget *parent)
{
    return new wNetwork(parent);
}
